package org.apache.maven.plugin.linkcheck;

/* ====================================================================
 *   Copyright 2001-2006 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.lang.StringEscapeUtils;

/**
 * An class containing the results of a single check of a link.
 * @author <a href="mailto:bwalding@apache.org">Ben Walding</a>
 * @author <a href="mailto:aheritier@apache.org">Arnaud Heritier</a>
 * @version $Id: LinkCheckResult.java 368935 2006-01-14 00:28:50Z aheritier $
 */
public final class LinkCheckResult
{
    private String status;

    private String target;

    private String errorMessage;

    /**
     * Returns the status.
     * @return String
     */
    public String getStatus()
    {
        return status;
    }

    /**
     * Sets the status.
     * @param status The status to set
     */
    public void setStatus( String status )
    {
        this.status = status;
    }

    /**
     * Returns the target.
     * @return String
     */
    public String getTarget()
    {
        return target;
    }

    /**
     * Sets the target.
     * @param target The target to set
     */
    public void setTarget( String target )
    {
        this.target = target;
    }

    /**
     * @return Returns the errorMessage.
     */
    public String getErrorMessage()
    {
        return errorMessage;
    }

    /**
     * @param errorMessage The errorMessage to set.
     */
    public void setErrorMessage( String errorMessage )
    {
        this.errorMessage = errorMessage;
    }

    /**
     * Creates an XML representation of this link check result
     * @return xml fragment representation of this result
     */
    public String toXML()
    {
        StringBuffer buf = new StringBuffer();
        buf.append( "    <result>\n" );
        buf.append( "      <target>" + StringEscapeUtils.escapeXml( getTarget() ) + "</target>\n" );
        buf.append( "      <status>" + getStatus() + "</status>\n" );
        buf.append( "      <errorMessage>" + StringEscapeUtils.escapeXml( getErrorMessage() ) + "</errorMessage>\n" );
        buf.append( "    </result>\n" );
        return buf.toString();
    }

}
