package org.apache.maven.plugin.linkcheck.validation;

import java.io.Serializable;

/* ====================================================================
 *   Copyright 2001-2005 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

/**
 * <p>
 *   This  class is used to return status responses from the
 *   validation handlers.  A persistent result means that it
 *   can be stored in the persistent cache and used across runs.
 * </p>
 * @author <a href="mailto:bwalding@apache.org">Ben Walding</a>
 * @author <a href="mailto:aheritier@apache.org">Arnaud Heritier</a>
 * @version $Id: LinkValidationResult.java 368935 2006-01-14 00:28:50Z aheritier $
 */
public class LinkValidationResult
    implements Serializable
{
    public static final int NOTMINE = 0;

    public static final int ERROR = 1;

    public static final int VALID = 2;

    public static final int UNKNOWN = 3;

    public static final int WARNING = 4;

    private final boolean persistent;

    private final int status;

    private final String errorMessage;

    public boolean isPersistent()
    {
        return persistent;
    }

    /**
     * Returns the status.
     * @return int
     */
    public int getStatus()
    {
        return status;
    }

    /**
     * @return Returns the errorMessage.
     */
    public String getErrorMessage()
    {
        return errorMessage;
    }

    public LinkValidationResult( int status, boolean persistent, String errorMessage )
    {
        this.status = status;
        this.persistent = persistent;
        this.errorMessage = errorMessage;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
        return persistent + "/" + status + "/" + errorMessage;
    }

}
